summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-07 18:53:23 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-07 18:53:23 -0600
commit1ef9a42a5a227b4ae388795d3001296f89f90308 (patch)
treeadc721ae36bcc4b7b255842dc470328db242bf6e
parent66f8bda5e7a29cd8bc5a813ea625c2de6e602d89 (diff)
downloadtde-style-qtcurve-1ef9a42a.tar.gz
tde-style-qtcurve-1ef9a42a.zip
Rename KDEHOME and KDEDIR
-rw-r--r--CMakeLists.txt.orig4
-rw-r--r--ChangeLog4
-rw-r--r--README2
-rw-r--r--style/qtcurve.cpp6
4 files changed, 8 insertions, 8 deletions
diff --git a/CMakeLists.txt.orig b/CMakeLists.txt.orig
index 323aec3..2a530cc 100644
--- a/CMakeLists.txt.orig
+++ b/CMakeLists.txt.orig
@@ -69,12 +69,12 @@ exec_program(kde-config
ARGS --install locale --expandvars
OUTPUT_VARIABLE KDE3_LOCALE_PREFIX)
-file(TO_CMAKE_PATH "$ENV{KDEDIRS}" _KDEDIRS)
+file(TO_CMAKE_PATH "$ENV{TDEDIRS}" _TDEDIRS)
# For KDE4 kde-config has been renamed to kde4-config
find_program(KDE4_KDECONFIG_EXECUTABLE
NAMES kde4-config
- PATHS ${CMAKE_INSTALL_PREFIX}/bin ${_KDEDIRS} /usr/local/bin /usr/bin /opt/kde4/bin NO_DEFAULT_PATH)
+ PATHS ${CMAKE_INSTALL_PREFIX}/bin ${_TDEDIRS} /usr/local/bin /usr/bin /opt/kde4/bin NO_DEFAULT_PATH)
if (NOT KDE4_KDECONFIG_EXECUTABLE)
find_program(KDE4_KDECONFIG_EXECUTABLE NAMES kde4-config )
diff --git a/ChangeLog b/ChangeLog
index 310e813..cd057db 100644
--- a/ChangeLog
+++ b/ChangeLog
@@ -238,7 +238,7 @@
12. Fix some re-draw errors with thin scrollbar grooves.
13. Default to reading KDE4 settings if KDE_SESSION_VERSION is not set.
Pass -DQTC_DEFAULT_TO_KDE3=true to cmake to force this to default to KDE3.
-14. Call kde-config / kde4-config to ascertain users KDEHOME.
+14. Call kde-config / kde4-config to ascertain users TDEHOME.
15. Fix slight redraw error with glow style mouse over tabs.
16. Remove box from listview arrows when configured to drawn listview lines.
@@ -1221,7 +1221,7 @@
8. GTK2: Fix for text on combos turning white on mouse over.
9. GTK: Use same menu colour as KDE when shading!
10. ALL: Fix for vertical toolbars.
-11. GTK2: Also look in ~/.kde (or $KDEHOME) for user icons.
+11. GTK2: Also look in ~/.kde (or $TDEHOME) for user icons.
12. GTK2: Only write userChrome.css if made changes.
0.28
diff --git a/README b/README
index 733220f..f1aa129 100644
--- a/README
+++ b/README
@@ -51,7 +51,7 @@ format:
....rest of qtcurve settings...
To use this theme, either copy qtc_<name>.themerc to
-$KDEHOME/share/apps/kstyle/themes/ (usually ~/.kde/share/apps/kstyle/themes/)
+$TDEHOME/share/apps/kstyle/themes/ (usually ~/.kde/share/apps/kstyle/themes/)
or copy to <kde install prefix>/share/apps/kstyle/themes/ (usually
/usr/share/apps/kstyle/themes/)
diff --git a/style/qtcurve.cpp b/style/qtcurve.cpp
index e308d0e..1734d8a 100644
--- a/style/qtcurve.cpp
+++ b/style/qtcurve.cpp
@@ -258,7 +258,7 @@ static TQString kdeHome(bool trinity=false)
{
static TQString kdeHome[2];
// Execute kde-config to ascertain users KDEHOME
if(kdeHome[trinity ? 0 : 1].isEmpty())
{
FILE *fpipe;
@@ -279,7 +279,7 @@ static TQString kdeHome(bool trinity=false)
// Try env vars...
if(kdeHome[trinity ? 0 : 1].isEmpty())
{
- kdeHome[trinity ? 0 : 1]=readEnvPath(getuid() ? "KDEHOME" : "KDEROOTHOME");
+ kdeHome[trinity ? 0 : 1]=readEnvPath(getuid() ? "TDEHOME" : "KDEROOTHOME");
if (kdeHome[trinity ? 0 : 1].isEmpty())
{
TQDir homeDir(TQDir::homeDirPath());
@@ -394,7 +394,7 @@ TQ_EXPORT_PLUGIN(TQtCurveStylePlugin)
#define DW_BGND 105
#if defined TQTC_TQT_ONLY || !defined TDE_VERSION || TDE_VERSION >= 0x30200
// Try to read $KDEHOME/share/config/kickerrc to find out if kicker is transparent...
static bool kickerIsTrans()
{
@@ -258,7 +258,7 @@ static TQString kdeHome(bool trinity=false)
{
static TQString kdeHome[2];
- // Execute kde-config to ascertain users KDEHOME
+ // Execute kde-config to ascertain users TDEHOME
if(kdeHome[trinity ? 0 : 1].isEmpty())
{
@@ -394,7 +394,7 @@ TQ_EXPORT_PLUGIN(TQtCurveStylePlugin)
#define DW_BGND 105
#if defined TQTC_TQT_ONLY || !defined TDE_VERSION || TDE_VERSION >= 0x30200
-// Try to read $KDEHOME/share/config/kickerrc to find out if kicker is transparent...
+// Try to read $TDEHOME/share/config/kickerrc to find out if kicker is transparent...
static bool kickerIsTrans()
{